ImageEmbedding

Struct ImageEmbedding 

pub struct ImageEmbedding { /* private fields */ }
Rust representation of the ImageEmbedding model

Implementations

Source

impl ImageEmbedding

pub fn try_new(options: ImageInitOptions) -> Result<Self>

Try to generate a new ImageEmbedding Instance

Uses the highest level of Graph optimization

Uses the total number of CPUs available as the number of intra-threads

pub fn try_new_from_user_defined( model: UserDefinedImageEmbeddingModel, options: ImageInitOptionsUserDefined, ) -> Result<Self>

Create a ImageEmbedding instance from model files provided by the user.

This can be used for ‘bring your own’ embedding models

pub fn list_supported_models() -> Vec<ModelInfo<ImageEmbeddingModel>>

Retrieve a list of supported models

pub fn get_model_info( model: &ImageEmbeddingModel, ) -> ModelInfo<ImageEmbeddingModel>

Get ModelInfo from ImageEmbeddingModel

pub fn embed_bytes( &mut self, images: &[&[u8]], batch_size: Option<usize>, ) -> Result<Vec<Embedding>>

Method to generate image embeddings for a Vec of image bytes

pub fn embed<S: AsRef<Path> + Send + Sync>( &mut self, images: impl AsRef<[S]>, batch_size: Option<usize>, ) -> Result<Vec<Embedding>>

Method to generate image embeddings for a collection of image paths.

Accepts anything that can be referenced as a slice of elements implementing AsRef<Path>, such as Vec<String>, Vec<PathBuf>, &[&str], or &[&Path].

pub fn embed_images( &mut self, imgs: Vec<DynamicImage>, ) -> Result<Vec<Embedding>>

Embed DynamicImages