#[non_exhaustive]pub struct RerankInitOptionsUserDefined {
pub execution_providers: Vec<ExecutionProviderDispatch>,
pub max_length: usize,
}Expand description
Options for initializing UserDefinedRerankerModel
Model files are held by the UserDefinedRerankerModel struct
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.execution_providers: Vec<ExecutionProviderDispatch>max_length: usizeTrait Implementations
Sourceimpl Clone for RerankInitOptionsUserDefined
impl Clone for RerankInitOptionsUserDefined
Sourcefn clone(&self) -> RerankInitOptionsUserDefined
fn clone(&self) -> RerankInitOptionsUserDefined
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RerankInitOptionsUserDefined
impl Debug for RerankInitOptionsUserDefined
Sourceimpl From<InitOptionsWithLength<RerankerModel>> for RerankInitOptionsUserDefined
Convert RerankInitOptions to RerankInitOptionsUserDefined
impl From<InitOptionsWithLength<RerankerModel>> for RerankInitOptionsUserDefined
Convert RerankInitOptions to RerankInitOptionsUserDefined
This is useful for when the user wants to use the same options for both the default and user-defined models
Sourcefn from(options: RerankInitOptions) -> Self
fn from(options: RerankInitOptions) -> Self
Converts to this type from the input type.